@@ -1,12 +1,3 @@
-context("utils")
-
-test_that("%||% works", {
-  expect_equal(1, 1 %||% 7)
-  expect_equal(1, NULL %||% 1)
-  expect_equal(1, c() %||% 1)
-  expect_equal(1, 1 %||% stop("oh no"))
-})
-
 test_that("add_email_scope() works", {
   email_url <- add_email_scope()
   expect_length(email_url, 1)
